"use strict";

var logger = require('../../logger');

/**
 * Class representing data in a specific layout.
 */
function LayoutData(layoutId, name) {
  this.setId(layoutId);
  this.setName(name);
  this.aliases = [];
  this.aliasById = [];
  this.reactions = [];
}

/**
 * Adds alias to the {@link LayoutData}
 * 
 * @param layoutAlias
 *          information about alias in a layout
 */
LayoutData.prototype.addAlias = function(layoutAlias) {
  this.aliases.push(layoutAlias);
  this.aliasById[layoutAlias.getId()] = layoutAlias;
};

/**
 * Adds reaction to the {@link LayoutData}
 * 
 * @param layoutReaction
 *          information about reaction in a layout
 */
LayoutData.prototype.addReaction = function(layoutReaction) {
  this.reactions.push(layoutReaction);
};

LayoutData.prototype.getId = function() {
  return this.id;
};

LayoutData.prototype.getName = function() {
  return this.name;
};

LayoutData.prototype.setId = function(id) {
  this.id = id;
};

LayoutData.prototype.setName = function(name) {
  this.name = name;
};

LayoutData.prototype.getDirectory = function() {
  return this._directory;
};

LayoutData.prototype.setDirectory = function(directory) {
  this._directory = directory;
};

LayoutData.prototype.updateAlias = function(layoutAlias) {
  if (this.aliasById[layoutAlias.getId()] === undefined) {
    logger.warn("Cannot update alias, it doesn't exist. Alias: ", layoutAlias.getId());
  } else {
    this.aliasById[layoutAlias.getId()].update(layoutAlias);
  }

};

LayoutData.prototype.getAliasById = function(id) {
  return this.aliasById[id];
};

module.exports = LayoutData;
