"use strict";

var ObjectWithListeners = require('../../ObjectWithListeners');

var Model = require('./MapModel');

function Project(data) {
  // call super constructor
  ObjectWithListeners.call(this);
  this.registerListenerType("onreload");

  if (data !== undefined) {
    this.loadFromData(data);
  }
}

// this class inherits from ObjectWithListeners class where generic methods for
// listeners are set
Project.prototype = Object.create(ObjectWithListeners.prototype);
Project.prototype.constructor = Project;

Project.prototype.loadFromData = function(data) {
  if (typeof data === "string") {
    // replace is due to some strange problem with serialization
    data = JSON.parse(data.replace(/\n/g, " "));
  }
  this.setId(parseInt(data.idObject));
  this.setProjectId(data.projectId);
  this.setVersion(data.version);
  this.setName(data.name);
  this.setDescription(data.description);
  this.setOverviewImages(data.overviewImageViews);
  this.setTopOverviewImage(data.topOverviewImage);

  this.setModel(new Model(data.map));

  this.callListeners("onreload");
};

Project.prototype.getId = function() {
  return this._id;
};

Project.prototype.setId = function(id) {
  this._id = id;
};
Project.prototype.getProjectId = function() {
  return this._projectId;
};

Project.prototype.setProjectId = function(projectId) {
  this._projectId = projectId;
};

Project.prototype.getVersion = function() {
  return this._version;
};

Project.prototype.setVersion = function(version) {
  this._version = version;
};

Project.prototype.getName = function() {
  return this._name;
};
Project.prototype.setName = function(name) {
  this._name = name;
};
Project.prototype.getModel = function() {
  return this._model;
};
Project.prototype.setModel = function(model) {
  this._model = model;
};

Project.prototype.getOverviewImages = function() {
  return this._overviewImages;
};
Project.prototype.setOverviewImages = function(overviewImages) {
  this._overviewImages = overviewImages;
};

Project.prototype.getTopOverviewImage = function() {
  return this._topOverviewImage;
};
Project.prototype.setTopOverviewImage = function(topOverviewImage) {
  this._topOverviewImage = topOverviewImage;
};

Project.prototype.getDescription = function() {
  return this._description;
};
Project.prototype.setDescription = function(description) {
  this._description = description;
};

module.exports = Project;
