"use strict";

var logger = require('../../logger');

/**
 * Class representing reaction data.
 * 
 * @param javaObject
 *          object deserialized from ajax query to the server side
 */
function Reaction(javaObject) {
  this.startLines = [];
  this.endLines = [];
  this.midLines = [];
  if (javaObject instanceof Reaction) {
    this.setId(javaObject.getId());
    this.setCenter(javaObject.getCenter());
    this.setModelId(javaObject.getModelId());

    this.startLines.push.apply(this.startLines, javaObject.getStartLines());
    this.endLines.push.apply(this.endLines, javaObject.getEndLines());
    this.midLines.push.apply(this.midLines, javaObject.getMidLines());

  } else {
    this.setId(javaObject.idObject);
    for (var i = 0; i < javaObject.lines.length; i++) {
      var line = javaObject.lines[i];
      if (line.type === "START") {
        this.startLines.push(line);
      } else if (line.type === "END") {
        this.endLines.push(line);
      } else if (line.type === "MIDDLE") {
        this.midLines.push(line);
      } else {
        logger.error("Unknown line type: " + line.type);
      }
    }
    this.setCenter(javaObject.centerPoint);
    this.setModelId(javaObject.modelId);
  }
}

Reaction.prototype.getId = function() {
  return this.id;
};

Reaction.prototype.setId = function(id) {
  this.id = id;
};

Reaction.prototype.getCenter = function() {
  return this._center;
};

Reaction.prototype.getLines = function() {
  var result = [];
  result = result.concat(this.startLines);
  result = result.concat(this.endLines);
  result = result.concat(this.midLines);
  return result;
};

Reaction.prototype.getMidLines = function() {
  return this.midLines;
};
Reaction.prototype.getStartLines = function() {
  return this.startLines;
};
Reaction.prototype.getEndLines = function() {
  return this.endLines;
};

Reaction.prototype.setCenter = function(center) {
  if (center === null || center === undefined) {
    logger.error("Setting undefined center: ", center);
  }
  this._center = center;
};

Reaction.prototype.getModelId = function() {
  return this._modelId;
};

Reaction.prototype.setModelId = function(modelId) {
  this._modelId = modelId;
};

module.exports = Reaction;
