"use strict";

var logger = require('./logger');

var GuiConnectorMock = {};

GuiConnectorMock.getImgPrefix = function() {
  return "../resources/images/";
};
GuiConnectorMock.tabNaviShow = function(direction) {
  GuiConnector.callListeners("onTabNaviShow: ", direction);
};
// list of available listener types
GuiConnectorMock.listeners = [];

GuiConnectorMock.getParams = [];

// add listener types
GuiConnectorMock.listeners.push("onTabNaviShow");

GuiConnectorMock.addListener = function(type, fun) {
  if (GuiConnector.listeners.indexOf(type) < 0) {
    throw "Unknown listener type: " + type;
  }

  if (typeof fun !== "function") {
    throw "Second parameter must be a function but \"" + typeof (fun)
        + "\" found.";
  }

  var listenerList = this.listeners[type];
  if (listenerList === null || listenerList === undefined) {
    listenerList = [];
    this.listeners[type] = listenerList;
  }
  listenerList.push(fun);
};

GuiConnectorMock.removeListener = function(type, fun) {
  if (GuiConnector.listeners.indexOf(type) < 0) {
    throw "Unknown listener type: " + type;
  }

  if (typeof fun !== "function") {
    throw "Second parameter must be a function but \"" + typeof (fun)
        + "\" found.";
  }

  var listenerList = this.listeners[type];
  if (listenerList !== undefined) {
    var index = listenerList.indexOf(fun);
    if (index > -1) {
      listenerList.splice(index, 1);
    }
  }
};

GuiConnectorMock.callListeners = function(type) {
  if (GuiConnector.listeners.indexOf(type) < 0) {
    throw "Unknown listener type: " + type;
  }
  var listenerList = this.listeners[type];
  if (listenerList !== undefined) {
    logger.debug("GuiConnector is calling: " + type + ". "
        + listenerList.length + " listeners found.");
    for ( var i in listenerList) {
      var e = {
        type : type,
        object : this,
      };
      listenerList[i](e);
    }
  } else {
    logger.debug("GuiConnector is calling: " + type + ". No listeners found.");
  }
};

GuiConnectorMock.openLoadingDialog = function() {
  logger.debug("[Mock] Open loadin dialog...");
};

/**
 * Closes window that informs user data data is being loaded from server.
 */
GuiConnectorMock.closeLoadingDialog = function() {
  logger.debug("[Mock] Hide loading dialog...");
};

GuiConnectorMock.getObjectByPrimefaceId = function(id) {
  var result = $('#' + id);
  return result;
};
GuiConnectorMock.getLcsbLogoImg = function() {
  return 'lcsb_logo.png';
};

GuiConnectorMock.getLoadingImg = function() {
  return "icons/ajax-loader.gif";
};

GuiConnectorMock.referenceToHtml = function(reference) {
  var result = "";
  if (reference.summary !== null && reference.summary !== undefined
      && reference.summary !== "") {
    result = '<div title="' + reference.summary + '">';
    result += '<a href="' + reference.link + '" target="_blank">'
        + reference.name + "</a>";
    // + reference.name + "(" + reference.type + ")</a>";
    result += "</div>";
    return result;
  } else {
    result = '<div><a href="' + reference.link + '" target="_blank">'
        + reference.name + "</a></div>";
    // + reference.name + "(" + reference.type + ")</a></div>";
    return result;
  }
};

GuiConnectorMock.showRightClickMenu = function(x, y) {
  logger.debug("Show right click menu:", x, y);
};

GuiConnectorMock.showSelectionMenu = function(x, y) {
  logger.debug("showSelectionMenu:", x, y);
};

GuiConnectorMock.isRightMenuVisible = function() {
  return this.contextMenuVisible;
};

GuiConnectorMock.updateMouseCoordinates = function(x, y) {
  this.xPos = x;
  this.yPos = y;
};

GuiConnectorMock.showGoogleMap = function() {
  logger.debug("show google map");
};

GuiConnectorMock.hideLegend = function() {
  logger.debug("hide legend");
};

GuiConnectorMock.setCustomMap = function(customMap) {
  if (customMap === undefined) {
    logger.error("CustomMap cannot be undefiend");
  }
  this._customMap = customMap;
};

GuiConnectorMock.getCustomMap = function() {
  return this._customMap;
};

module.exports = GuiConnectorMock;
