'use strict';

var logger = require('./logger');
var functions = require('../../main/js/Functions');

var OriginalServerConnector = require('../../main/js/ServerConnector');

var fs = require('fs');
var request = require('request');

var ServerConnectorMock = OriginalServerConnector;

ServerConnectorMock.init = function() {
  this._customMap = null;
  ServerConnectorMock.selectedLayout = null;
  ServerConnectorMock.zoomLevel = 2;
  ServerConnectorMock.listeners = [];
  ServerConnectorMock._waitingForAliasLayoutData = 0;
  ServerConnectorMock._waitingForAliasLayoutDataByLayoutId = [];

  ServerConnectorMock._waitingFullAliasLayoutData = 0;
  ServerConnectorMock._waitingFullAliasLayoutDataById = [];

  ServerConnectorMock._waitingForAliasData = 0;
  ServerConnectorMock._waitingForAliasDataByAliasId = [];

  ServerConnectorMock._waitingForReactionLayoutData = 0;
  ServerConnectorMock._waitingForReactionLayoutDataByLayoutId = [];

  ServerConnectorMock._waitingForReactionData = 0;
  ServerConnectorMock._waitingForReactionDataByReactionId = [];

  ServerConnectorMock.selectedPolygon = null;
  ServerConnectorMock.exportModelId = null;

  // add listener types
  ServerConnectorMock.listeners.push("onActualizeSessionData");
  ServerConnectorMock.listeners.push("onActualizeParams");
  ServerConnectorMock.listeners.push("onRetreiveActiveAliasesForLayout");
  ServerConnectorMock.listeners.push("onRetreiveFullAliasesForLayout");
  ServerConnectorMock.listeners.push("onRetreiveActiveReactionsForLayout");
  ServerConnectorMock.listeners.push("onRetreiveLightAliases");
  ServerConnectorMock.listeners.push("onRetreiveFullAliases");
  ServerConnectorMock.listeners.push("onRetrieveMissingReactions");
  ServerConnectorMock.listeners.push("onRetreiveLightReactions");
  ServerConnectorMock.listeners.push("onSendClearRequest");
  ServerConnectorMock.listeners.push("onSendOverlayDetailDataRequest");
  ServerConnectorMock.listeners.push("onRequestUpdateCommentList");
  ServerConnectorMock.listeners.push("onSearchByCoord");
};
ServerConnectorMock.init();

ServerConnectorMock.addListener = function(type, fun) {
  if (ServerConnectorMock.listeners.indexOf(type) < 0) {
    throw "Unknown listener type: " + type;
  }

  if (typeof fun !== "function") {
    throw "Second parameter must be a function but \"" + typeof (fun) + "\" found.";
  }

  var listenerList = this.listeners[type];
  if (listenerList === null || listenerList === undefined) {
    listenerList = [];
    this.listeners[type] = listenerList;
  }
  listenerList.push(fun);
};

ServerConnectorMock.removeListener = function(type, fun) {
  if (ServerConnectorMock.listeners.indexOf(type) < 0) {
    throw "Unknown listener type: " + type;
  }

  if (typeof fun !== "function") {
    throw "Second parameter must be a function but \"" + typeof (fun) + "\" found.";
  }

  var listenerList = this.listeners[type];
  if (listenerList !== null && listenerList !== undefined) {
    var index = listenerList.indexOf(fun);
    if (index > -1) {
      listenerList.splice(index, 1);
    }
  }
};

ServerConnectorMock.callListeners = function(type, param) {

  if (ServerConnectorMock.listeners.indexOf(type) < 0) {
    throw "Unknown listener type: " + type;
  }

  var listenerList = this.listeners[type];
  if (listenerList !== null && listenerList !== undefined) {
    logger.debug("ServerConnector is calling: " + type + ". " + listenerList.length + " listeners found.");
    for ( var i in listenerList) {
      var e = {};
      e.type = type;
      e.object = this;
      e.param = param;
      listenerList[i](e);
    }
  } else {
    logger.debug("ServerConnector is calling: " + type + ". No listeners found.");
  }
};

ServerConnectorMock.getLogoImg = function() {
  return "marker/empty.png";
};

ServerConnectorMock.getZoomLevel = function() {
  return this.zoomLevel;
};

ServerConnectorMock.setZoomLevel = function(value) {
  this.zoomLevel = value;
};

ServerConnectorMock.setCenterCoordinateX = function(value) {
  this.centerCoordinateX = value;
};

ServerConnectorMock.getCenterCoordinateX = function() {
  return this.centerCoordinateX;
};

ServerConnectorMock.setCenterCoordinateY = function(value) {
  this.centerCoordinateY = value;
};

ServerConnectorMock.getCenterCoordinateY = function() {
  return this.centerCoordinateY;
};

ServerConnectorMock.setSelectedLayout = function(value) {
  this.selectedLayout = value;
};

ServerConnectorMock.getSelectedLayout = function() {
  return this.selectedLayout;
};

ServerConnectorMock.setSelectedPolygon = function(value) {
  this.selectedPolygon = value;
};

ServerConnectorMock.getSelectedPolygon = function() {
  return this.selectedPolygon;
};

ServerConnectorMock.setExportModelId = function(value) {
  this.exportModelId = value;
};

ServerConnectorMock.getExportModelId = function() {
  return this.exportModelId;
};

ServerConnectorMock.actualizeSessionData = function() {
  ServerConnectorMock.callListeners("onActualizeSessionData");
};

ServerConnectorMock.actualizeParams = function() {
  ServerConnectorMock.callListeners("onActualizeParams");
};

ServerConnectorMock.retreiveActiveAliasesForLayout = function(identifier) {
  ServerConnectorMock.callListeners("onRetreiveActiveAliasesForLayout", identifier);
};
ServerConnectorMock.retreiveFullAliasesForLayout = function(layoutId, aliasId, modelId) {
  ServerConnectorMock.callListeners("onRetreiveFullAliasesForLayout", layoutId, aliasId, modelId);
};

ServerConnectorMock.retreiveActiveReactionsForLayout = function(identifier) {
  ServerConnectorMock.callListeners("onRetreiveActiveReactionsForLayout", identifier);
};

ServerConnectorMock.retreiveLightAliases = function(ids) {
  ServerConnectorMock.callListeners("onRetreiveLightAliases", ids);
};

ServerConnectorMock.retreiveFullAliases = function(ids) {
  ServerConnectorMock.callListeners("onRetreiveFullAliases", ids);
};

ServerConnectorMock.retreiveLightReactions = function(ids) {
  ServerConnectorMock.callListeners("onRetreiveLightReactions", ids);
};

ServerConnectorMock.setVisibleLayouts = function(value) {
  this.visibleLayouts = value;
};

ServerConnectorMock.getVisibleLayouts = function() {
  return this.visibleLayouts;
};

ServerConnectorMock.sendClearRequest = function(overlayName) {
  ServerConnectorMock.callListeners("onSendClearRequest", overlayName);
};

ServerConnectorMock.sendOverlayDetailDataRequest = function(overlayName, identifiedElement) {
  ServerConnectorMock.callListeners("onSendOverlayDetailDataRequest", overlayName, identifiedElement);
};

ServerConnectorMock.requestUpdateCommentList = function(modelId, latLngCoordinates) {
  ServerConnectorMock.callListeners("onRequestUpdateCommentList", [ modelId, latLngCoordinates ]);
};

ServerConnectorMock.searchByCoord = function(modelId, latLngCoordinates) {
  ServerConnectorMock.callListeners("onSearchByCoord", [ modelId, latLngCoordinates ]);
};

ServerConnectorMock.isWaitingForFullAliasLayoutData = function(layoutId, aliasId) {
  if (!functions.isInt(layoutId)) {
    logger.error("isWaitingForFullAliasLayoutData layoutId must be integer, but found: ", layoutId);
  }
  if (!functions.isInt(aliasId)) {
    logger.error("isWaitingForFullAliasLayoutData aliasId must be integer, but found: ", aliasId);
  }

  var val = this._waitingFullAliasLayoutDataById[layoutId + "-" + aliasId];
  if (val === null || val === undefined) {
    return false;
  }
  return val;
};

ServerConnectorMock.isWaitingForData = function() {
  var result = (this._waitingForAliasLayoutData !== 0) || //
  (this._waitingForAliasData !== 0) || //
  (this._waitingForReactionLayoutData !== 0) || //
  (this._waitingForReactionData !== 0);
  return result;
};

ServerConnectorMock.setCustomMap = function(customMap) {
  this._customMap = customMap;
};

ServerConnectorMock.getCustomMap = function() {
  return this._customMap;
};

ServerConnectorMock.addOverlayCollection = function(overlay) {
  logger.debug("Adding overlay: " + overlay);
};

ServerConnectorMock.sendRefreshRequest = function(overlayName) {
  logger.debug("Send refresh request: " + overlayName);
};

ServerConnectorMock.getMaxOverlayColorInt = function() {
  return 0xFF0000;
};

ServerConnectorMock.getMinOverlayColorInt = function() {
  return 0x00FF00;
};

ServerConnectorMock.readFile = function(url) {
  return new Promise(function(resolve, reject) {
    if (url.indexOf("http") === 0) {
      request.get(url, function(error, response, body) {
        if (error) {
          reject(error);
        } else if (response.statusCode !== 200) {
          reject(response);
        } else {
          resolve(body);
        }
      });
    } else {
      fs.readFile(url, 'utf8', function(err, content) {
        if (err) {
          reject(err);
        } else {
          resolve(content);
        }
      });
    }
  });
};

ServerConnectorMock.getServerBaseUrl = function() {
  return "./testFiles/apiCalls/";
};

ServerConnectorMock.getProjectUrl = function(projectId, token) {
  return this.getServerBaseUrl() + "project/getMetaData-" + projectId + "-" + token;
};

ServerConnectorMock.getConfigurationUrl = function(token) {
  return this.getServerBaseUrl() + "configuration/getAllValues-" + token;
};

module.exports = ServerConnectorMock;
