"use strict";

require("./mocha-config");

var AbstractCustomMap = require("../../main/js/map/AbstractCustomMap");
var CustomMap = require("../../main/js/map/CustomMap");
var CustomMapOptions = require("../../main/js/map/CustomMapOptions");
var LayoutData = require("../../main/js/map/data/LayoutData");
var Model = require("../../main/js/map/data/MapModel");
var Project = require("../../main/js/map/data/Project");

function Helper() {
  this.idCounter = 1000000;
}

Helper.prototype.createProject = function() {
  var result = new Project();
  result.setId(this.idCounter++);
  result.setModel(this.createModel());
  return result;
};

Helper.prototype.createModel = function() {
  var result = new Model();
  result.setId(this.idCounter++);
  result.setTileSize(256);
  result.setWidth(26547.3333333333);
  result.setHeight(800);
  result.setMaxZoom(8);
  result.setMinZoom(2);
  
  var layout = this.createLayout();
  result.addLayout(layout);
  return result;
};


Helper.prototype.createLayout= function() {
  var layout = new LayoutData();
  layout.setId(this.idCounter++);
  layout.setName("testLayout"+layout.getId());
  return layout;
};

Helper.prototype.createGoogleMap = function() {
  var result = new google.maps.Map(testDiv, {
    center : {
      lat : -34.397,
      lng : 150.644
    },
    scrollwheel : false,
    zoom : 8
  });
  return result;
};

Helper.prototype.createCustomMapOptions = function() {
  var project = this.createProject();
  var map = this.createGoogleMap();
  var result = new CustomMapOptions({
    markerOptimization : true,
    project : project,
    map : map
  });

  return result;
};

Helper.prototype.createAbstractCustomMap = function() {
  var options = this.createCustomMapOptions();
  var result = new AbstractCustomMap(options.getProject().getModel(), options);

  return result;
};

Helper.prototype.createCustomMap = function() {
  var options = this.createCustomMapOptions();
  var result = new CustomMap(options);
  return result;
};

module.exports = Helper;
