"use strict";

var functions = require('../../../../main/js/Functions');

var Helper = require('../../Helper');

var Alias = require('../../../../main/js/map/data/Alias');
var AliasInfoWindow = require('../../../../main/js/map/window/AliasInfoWindow');
var IdentifiedElement = require('../../../../main/js/map/data/IdentifiedElement');
var LayoutAlias = require('../../../../main/js/map/data/LayoutAlias');
var OverlayCollection = require('../../../../main/js/map/overlay/OverlayCollection');

var assert = require('assert');

describe(
    'AliasInfoWindow',
    function() {
      var helper;
      before(function() {
        helper = new Helper();
      });

      it("AliasInfoWindow Constructor", function() {
        var map = helper.createCustomMap();

        var aliasWindow = new AliasInfoWindow(null, map);

        assert.equal(null, aliasWindow.alias);
        assert.equal(map, aliasWindow.customMap);
        assert.ok(aliasWindow.getContent().innerHTML.indexOf("loading") >= 0);
      });

      it("AliasInfoWindow Constructor 2", function() {
        var map = helper.createAbstractCustomMap();
        map.getTopMap = function() {
          var mockObj = {};
          mockObj.getOverlayDataForAlias = function() {
            return [];
          };
          return mockObj;
        };

        var jsonString = '{"bounds":{"x":190,"y":44,"width":80,"height":40},"modelId":57,"idObject":18554}';
        var javaObject = JSON.parse(jsonString);
        var alias = new Alias(javaObject);

        var aliasWindow = new AliasInfoWindow(alias, map);

        assert.equal(alias, aliasWindow.alias);
        assert.equal(map, aliasWindow.customMap);
        assert.ok(aliasWindow.getContent().innerHTML.indexOf("loading") > -1);
      });

      it(
          "AliasInfoWindow Constructor 3",
          function() {
            var map = helper.createAbstractCustomMap();
            map.getTopMap = function() {
              var mockObj = {};
              mockObj.getOverlayDataForAlias = function() {
                return [];
              };
              mockObj.getSelectedLayouts = function() {
                var result = [];
                result.push(573);
                return result;
              };
              return mockObj;
            };

            // create a mock function that will return list of layouts alias
            // data
            map.getAliasVisibleLayoutsData = function() {
              var result = [];
              result.push(new LayoutAlias({
                idObject : "1",
                color : {
                  falpha : 0,
                  value : -8388737
                }
              }));
              result.push(null);
              return result;
            };
            map.getVisibleLayoutNames = function() {
              return [ "name 1", "name 2" ];
            };

            var jsonString = '{"notes":"","type":"Protein","name":"s1","synonyms":[],"formerSymbols":[],"references":[],"other":[],"bounds":{"x":59,"y":73,"width":80,"height":40},"modelId":54,"idObject":18552}';
            var javaObject = JSON.parse(jsonString);
            var alias = new Alias(javaObject);

            var aliasWindow = new AliasInfoWindow(alias, map);

            assert.equal(alias, aliasWindow.alias);
            assert.equal(map, aliasWindow.customMap);
            assert.ok(aliasWindow.getContent().innerHTML.indexOf("loading") === -1);
          });

      it(
          "AliasInfoWindow update test",
          function() {
            var map = helper.createAbstractCustomMap();

            map.getTopMap = function() {
              var mockObj = {};
              mockObj.getOverlayDataForAlias = function() {
                return [];
              };
              mockObj.getSelectedLayouts = function() {
                var result = [];
                result.push(444);
                return result;
              };
              return mockObj;
            };

            // create a mock function that will return list of layouts alias
            // data
            map.getAliasVisibleLayoutsData = function() {
              var result = [];
              result.push(new LayoutAlias({
                idObject : "1",
                color : {
                  falpha : 0,
                  value : -8388737
                }
              }));
              result.push(null);
              return result;
            };
            map.getVisibleLayoutNames = function() {
              return [ "name 1", "name 2" ];
            };

            var jsonString = '{"bounds":{"x":190,"y":44,"width":80,"height":40},"modelId":57,"idObject":18554}';
            var javaObject = JSON.parse(jsonString);
            var alias = new Alias(javaObject);

            var aliasWindow = new AliasInfoWindow(alias, map);

            jsonString = '{"notes":"","type":"Protein","name":"s1","synonyms":[],"formerSymbols":[],"references":[],"other":[],"bounds":{"x":59,"y":73,"width":80,"height":40},"modelId":54,"idObject":18552}';
            javaObject = JSON.parse(jsonString);
            alias.update(javaObject);

            aliasWindow.update();
            assert.ok(aliasWindow.getContent().innerHTML.indexOf("loading") === -1);
            assert.ok(aliasWindow.getContent().innerHTML.indexOf("name 1") > -1);
          });

      it("AliasInfoWindow createOverlayInfoDiv", function() {
        var modelId = 2;
        var aliasId = 3;

        var map = helper.createCustomMap();

        var oc = new OverlayCollection(map, 'test name', false, true);

        var alias = new Alias({
          idObject : aliasId,
          modelId : modelId,
          bounds : {
            x : 0,
            y : 2,
            width : 3,
            height : 4
          }
        });
        alias.setType("RNA");
        var aliasWindow = new AliasInfoWindow(alias, map);

        var data = oc.getDetailDataByIdentifiedElement(new IdentifiedElement(alias), true);
        data['test'] = {
          xField : 'y_param'
        };

        var overlayDiv = aliasWindow.createOverlayInfoDiv(oc, data);

        assert.ok(functions.isDomElement(overlayDiv));
        assert.ok(overlayDiv.innerHTML.indexOf('xField') >= 0);

      });

      it("AliasInfoWindow createDrugOverlayInfoDiv", function() {
        var modelId = 2;
        var aliasId = 3;

        var map = helper.createCustomMap();

        var oc = new OverlayCollection(map, 'drug', true, true);

        var alias = new Alias({
          idObject : aliasId,
          modelId : modelId,
          bounds : {
            x : 0,
            y : 2,
            width : 3,
            height : 4
          }
        });
        alias.setType("RNA");
        var aliasWindow = new AliasInfoWindow(alias, map);

        var data = oc.getDetailDataByIdentifiedElement(new IdentifiedElement(alias), true);

        var emptyOverlayDiv = aliasWindow.createOverlayInfoDiv(oc, data);

        // check if we have row with info about empty drug list
        assert.ok(emptyOverlayDiv.innerHTML.indexOf("colspan") >= 0);

        data['test drug'] = {
          databaseSource : {},
          references : [ {} ]
        };

        var overlayDiv = aliasWindow.createOverlayInfoDiv(oc, data);

        assert.ok(functions.isDomElement(overlayDiv));
        assert.ok(overlayDiv.innerHTML.indexOf('test drug') >= 0);

      });

      it("AliasInfoWindow createCommentOverlayInfoDiv", function() {
        var modelId = 2;
        var aliasId = 3;

        var map = helper.createCustomMap();

        var oc = new OverlayCollection(map, 'comment', false, true);

        var alias = new Alias({
          idObject : aliasId,
          modelId : modelId,
          bounds : {
            x : 0,
            y : 2,
            width : 3,
            height : 4
          }
        });
        alias.setType("RNA");
        var aliasWindow = new AliasInfoWindow(alias, map);

        var commentId = 4509;
        var data = oc.getDetailDataByIdentifiedElement(new IdentifiedElement(alias), true);
        data[0] = {
          commentId : commentId,
          commentContent : 'test comment Content'
        };
        data['__FULL__'] = null;

        var overlayDiv = aliasWindow.createOverlayInfoDiv(oc, data);

        assert.ok(functions.isDomElement(overlayDiv));
        assert.ok(overlayDiv.innerHTML.indexOf('test comment Content') >= 0);
        assert.ok(overlayDiv.innerHTML.indexOf(commentId) >= 0);

      });

      it("AliasInfoWindow Constructor", function() {
        var map = helper.createAbstractCustomMap();

        var aliasWindow = new AliasInfoWindow(null, map);

        assert.ok(functions.isDomElement(aliasWindow.createWaitingContentDiv()));
      });
    });
